@@ -11,6 +11,8 @@ from .stream import GStream
 
 class Kola(kola.Kola):
 
+    server = None
+
     def __init__(self, server_class=None, conn_class=None):
         super(Kola, self).__init__()
         self.repeat_timer_func_list = []
@@ -26,8 +28,8 @@ class Kola(kola.Kola):
             monkey.patch_all()
 
         self._start_repeat_timers()
-        server = self.server_class((host, port), self.handle_stream)
-        server.serve_forever()
+        self.server = self.server_class((host, port), self.handle_stream)
+        self.server.serve_forever()
 
     def register_blueprint(self, blueprint):
         blueprint.register2app(self)
